==> jc-1.4.0.tar.gz: soot/jimple/spark/pag/AllocDotField.h <==
// public class soot.jimple.spark.pag.AllocDotField

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 139b6e5c52f5e474 soot_jimple_spark_pag_AllocDotField
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node

// header file dependencies
// @dep_header soot_jimple_spark_pag_Node

#include "soot/jimple/spark/pag/Node.h"

#ifndef _JC_soot_jimple_spark_pag_AllocDotField_H_
#define _JC_soot_jimple_spark_pag_AllocDotField_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_AllocNode$object;
struct _jc_soot_jimple_spark_pag_SparkField$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_AllocDotField$sub_refs	_jc_soot_jimple_spark_pag_AllocDotField$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_AllocDotField$sub_nonrefs	_jc_soot_jimple_spark_pag_AllocDotField$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_AllocDotField$refs	_jc_soot_jimple_spark_pag_AllocDotField$refs;
typedef struct _jc_soot_jimple_spark_pag_AllocDotField$nonrefs	_jc_soot_jimple_spark_pag_AllocDotField$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_AllocDotField$object	_jc_soot_jimple_spark_pag_AllocDotField$object;

typedef const struct _jc_soot_jimple_spark_pag_AllocDotField$vmethods	_jc_soot_jimple_spark_pag_AllocDotField$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_AllocDotField$vtable	_jc_soot_jimple_spark_pag_AllocDotField$vtable;
typedef const struct _jc_soot_jimple_spark_pag_AllocDotField$vtype	_jc_soot_jimple_spark_pag_AllocDotField$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_AllocDotField$method$_init$d77779e035b34ec6(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_soot_jimple_spark_pag_AllocNode$object *_jc_soot_jimple_spark_pag_AllocDotField$method$getBase$ab6f3a5b5f4454ef(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *);
extern struct _jc_object *_jc_soot_jimple_spark_pag_AllocDotField$method$getField$fac4cba8dcbd3764(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_AllocDotField$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_AllocDotField$method_info$getBase$ab6f3a5b5f4454ef;
extern _jc_method _jc_soot_jimple_spark_pag_AllocDotField$method_info$getField$fac4cba8dcbd3764;
extern _jc_method _jc_soot_jimple_spark_pag_AllocDotField$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_AllocDotField$vmethods {
	struct _jc_soot_jimple_spark_pag_AllocNode$object	*(*getBase$ab6f3a5b5f4454ef)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *);
	struct _jc_object	*(*getField$fac4cba8dcbd3764)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *);
};

// Vtable
struct _jc_soot_jimple_spark_pag_AllocDotField$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_AllocDotField$vmethods	soot_jimple_spark_pag_AllocDotField;
};

// Vtype
struct _jc_soot_jimple_spark_pag_AllocDotField$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_AllocDotField$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_AllocDotField$sub_refs {
	struct _jc_soot_jimple_spark_pag_AllocNode$object	*base;
	struct _jc_object	*field;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_AllocDotField$refs {
    _jc_soot_jimple_spark_pag_AllocDotField$sub_refs	soot_jimple_spark_pag_AllocDotField;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_AllocDotField$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_AllocDotField$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_AllocDotField$sub_nonrefs	soot_jimple_spark_pag_AllocDotField;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_AllocDotField$object {
	_jc_soot_jimple_spark_pag_AllocDotField$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_AllocDotField$vtype	*vtype;
	_jc_soot_jimple_spark_pag_AllocDotField$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_AllocDotField$vtype _jc_soot_jimple_spark_pag_AllocDotField$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_AllocDotField, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_AllocDotField$class_object;

#endif	/* _JC_soot_jimple_spark_pag_AllocDotField_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/pag/AllocDotField.h <==
// public class soot.jimple.spark.pag.AllocDotField

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 139b6e5c52f5e474 soot_jimple_spark_pag_AllocDotField
// @dep_class 1f5a22eefeebbf06 soot_jimple_spark_pag_Node

// header file dependencies
// @dep_header soot_jimple_spark_pag_Node

#include "soot/jimple/spark/pag/Node.h"

#ifndef _JC_soot_jimple_spark_pag_AllocDotField_H_
#define _JC_soot_jimple_spark_pag_AllocDotField_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_spark_pag_AbstractPAG$object;
struct _jc_soot_jimple_spark_pag_AllocNode$object;
struct _jc_soot_jimple_spark_pag_SparkField$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_pag_AllocDotField$sub_refs	_jc_soot_jimple_spark_pag_AllocDotField$sub_refs;
typedef struct _jc_soot_jimple_spark_pag_AllocDotField$sub_nonrefs	_jc_soot_jimple_spark_pag_AllocDotField$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_pag_AllocDotField$refs	_jc_soot_jimple_spark_pag_AllocDotField$refs;
typedef struct _jc_soot_jimple_spark_pag_AllocDotField$nonrefs	_jc_soot_jimple_spark_pag_AllocDotField$nonrefs;
typedef struct _jc_soot_jimple_spark_pag_AllocDotField$object	_jc_soot_jimple_spark_pag_AllocDotField$object;

typedef const struct _jc_soot_jimple_spark_pag_AllocDotField$vmethods	_jc_soot_jimple_spark_pag_AllocDotField$vmethods;
typedef const struct _jc_soot_jimple_spark_pag_AllocDotField$vtable	_jc_soot_jimple_spark_pag_AllocDotField$vtable;
typedef const struct _jc_soot_jimple_spark_pag_AllocDotField$vtype	_jc_soot_jimple_spark_pag_AllocDotField$vtype;

// Constructors
extern void _jc_soot_jimple_spark_pag_AllocDotField$method$_init$d77779e035b34ec6(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *, struct _jc_soot_jimple_spark_pag_AbstractPAG$object *, struct _jc_soot_jimple_spark_pag_AllocNode$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_jimple_spark_pag_AllocNode$object *_jc_soot_jimple_spark_pag_AllocDotField$method$getBase$ab6f3a5b5f4454ef(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_spark_pag_AllocDotField$method$getField$fac4cba8dcbd3764(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_spark_pag_AllocDotField$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_pag_AllocDotField$method_info$getBase$ab6f3a5b5f4454ef;
extern _jc_method _jc_soot_jimple_spark_pag_AllocDotField$method_info$getField$fac4cba8dcbd3764;
extern _jc_method _jc_soot_jimple_spark_pag_AllocDotField$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_spark_pag_AllocDotField$vmethods {
	struct _jc_soot_jimple_spark_pag_AllocNode$object	*(*getBase$ab6f3a5b5f4454ef)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getField$fac4cba8dcbd3764)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_spark_pag_AllocDotField$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_pag_AllocDotField$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_pag_Node$vmethods	soot_jimple_spark_pag_Node;
	_jc_soot_jimple_spark_pag_AllocDotField$vmethods	soot_jimple_spark_pag_AllocDotField;
};

// Vtype
struct _jc_soot_jimple_spark_pag_AllocDotField$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_pag_AllocDotField$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_AllocDotField$sub_refs {
	struct _jc_soot_jimple_spark_pag_AllocNode$object	*base;
	struct _jc_object	*field;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_pag_AllocDotField$refs {
    _jc_soot_jimple_spark_pag_AllocDotField$sub_refs	soot_jimple_spark_pag_AllocDotField;
    _jc_soot_jimple_spark_pag_Node$sub_refs	soot_jimple_spark_pag_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_pag_AllocDotField$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_pag_AllocDotField$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_pag_Node$sub_nonrefs	soot_jimple_spark_pag_Node;
    _jc_soot_jimple_spark_pag_AllocDotField$sub_nonrefs	soot_jimple_spark_pag_AllocDotField;
};

// Object instance structure
struct _jc_soot_jimple_spark_pag_AllocDotField$object {
	_jc_soot_jimple_spark_pag_AllocDotField$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_pag_AllocDotField$vtype	*vtype;
	_jc_soot_jimple_spark_pag_AllocDotField$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_pag_AllocDotField$vtype _jc_soot_jimple_spark_pag_AllocDotField$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_pag_AllocDotField, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_pag_AllocDotField$class_object;

#endif	/* _JC_soot_jimple_spark_pag_AllocDotField_H_ */
